/*
 * TeleDart - Telegram Bot API for Dart
 * Copyright (C) 2019  Dino PH Leung
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

part of '../model.dart';

/// This object represents a general file (as opposed to [photos], [voice messages] and [audio files]).
///
/// https://core.telegram.org/bots/api#document
///
/// [photos]: https://core.telegram.org/bots/api#photosize
/// [voice messages]: https://core.telegram.org/bots/api#voice
/// [audio files]: https://core.telegram.org/bots/api#audio
@JsonSerializable(fieldRename: FieldRename.snake)
class Document {
  String fileId;
  String fileUniqueId;
  PhotoSize? thumbnail;
  String? fileName;
  String? mimeType;
  int? fileSize;
  Document({
    required this.fileId,
    required this.fileUniqueId,
    this.thumbnail,
    this.fileName,
    this.mimeType,
    this.fileSize,
  });
  factory Document.fromJson(Map<String, dynamic> json) =>
      _$DocumentFromJson(json);
  Map<String, dynamic> toJson() => _$DocumentToJson(this);
}
